@@ -329,7 +329,7 @@ This code may be distributed under the same conditions as Perl itself.
 package Tk::JFileDialog;
 
 use vars qw($VERSION);
-$VERSION = '1.61';
+$VERSION = '1.62';
 
 require 5.002;
 use Tk;
@@ -720,10 +720,10 @@ sub getHistUsePathButton
 sub IsNum
 {
 	my($parm) = @_;
-	my($warnSave) = $;
-	$ = 0;
+	my($warnSave) = $_;
+	$_ = 0;
 	my($res) = (($parm + 0) eq $parm);
-	$ = $warnSave;
+	$_ = $warnSave;
 	return $res;
 }
 
